@@ -352,7 +352,7 @@ create_errors_to_message_hash (void)
   g_hash_table_insert (errors, TP_ERROR_STR_CONNECTION_LOST,
     _("Connection has been lost"));
   g_hash_table_insert (errors, TP_ERROR_STR_ALREADY_CONNECTED,
-    _("This resource is already connected to the server"));
+    _("This account is already connected to the server"));
   g_hash_table_insert (errors, TP_ERROR_STR_CONNECTION_REPLACED,
     _("Connection has been replaced by a new connection using the "
     "same resource"));
@@ -1195,3 +1195,23 @@ empathy_create_individual_from_tp_contact (TpContact *contact)
 
   return individual;
 }
+
+/* Look for a FolksIndividual containing @contact as one of his persona
+ * and create one if needed */
+FolksIndividual *
+empathy_ensure_individual_from_tp_contact (TpContact *contact)
+{
+  EmpathyIndividualManager *mgr;
+  FolksIndividual *individual;
+
+  mgr = empathy_individual_manager_dup_singleton ();
+  individual = empathy_individual_manager_lookup_by_contact (mgr, contact);
+
+  if (individual != NULL)
+    g_object_ref (individual);
+  else
+    individual = empathy_create_individual_from_tp_contact (contact);
+
+  g_object_unref (mgr);
+  return individual;
+}
