@@ -220,28 +220,40 @@ accounts_dialog_status_infobar_set_message (EmpathyAccountsDialog *dialog,
 }
 
 static void
-accounts_dialog_enable_account_cb (GObject *account,
+accounts_dialog_enable_account_cb (GObject *object,
     GAsyncResult *result,
     gpointer user_data)
 {
+  TpAccount *account = TP_ACCOUNT (object);
+  gboolean enable = GPOINTER_TO_UINT (user_data);
   GError *error = NULL;
+  TpAccountManager *am;
 
-  tp_account_set_enabled_finish (TP_ACCOUNT (account), result, &error);
-
-  if (error != NULL)
+  if (!tp_account_set_enabled_finish (account, result, &error))
     {
       DEBUG ("Could not enable the account: %s", error->message);
       g_error_free (error);
+      return;
     }
-  else
-    {
-      TpAccountManager *am = tp_account_manager_dup ();
 
-      empathy_connect_new_account (TP_ACCOUNT (account), am);
+  /* tp_account_is_enabled() is not updated yet at this point */
+  if (enable)
+    {
+      am = tp_account_manager_dup ();
+
+      empathy_connect_new_account (account, am);
       g_object_unref (am);
     }
 }
 
+static void
+enable_and_connect_account (TpAccount *account,
+    gboolean enable)
+{
+  tp_account_set_enabled_async (account, enable,
+      accounts_dialog_enable_account_cb, GUINT_TO_POINTER (enable));
+}
+
 static void
 accounts_dialog_enable_switch_active_cb (GtkSwitch *sw,
     GParamSpec *spec,
@@ -249,6 +261,7 @@ accounts_dialog_enable_switch_active_cb (GtkSwitch *sw,
 {
   EmpathyAccountSettings *settings;
   TpAccount *account;
+  gboolean enable;
 
   settings = accounts_dialog_model_get_selected_settings (dialog);
   if (settings == NULL)
@@ -258,8 +271,9 @@ accounts_dialog_enable_switch_active_cb (GtkSwitch *sw,
   if (account == NULL)
     return;
 
-  tp_account_set_enabled_async (account, gtk_switch_get_active (sw),
-      accounts_dialog_enable_account_cb, NULL);
+  enable = gtk_switch_get_active (sw);
+
+  enable_and_connect_account (account, enable);
 }
 
 static void
@@ -303,6 +317,23 @@ account_is_selected (EmpathyAccountsDialog *dialog,
   return account == selected_account;
 }
 
+static gboolean
+account_can_be_enabled (TpAccount *account)
+{
+  TpStorageRestrictionFlags storage_restrictions;
+
+  storage_restrictions = tp_account_get_storage_restrictions (account);
+  if (storage_restrictions & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED)
+    return FALSE;
+
+  /* Butterfly accounts shouldn't be used any more */
+  if (!tp_strdiff (tp_account_get_connection_manager (account),
+        "butterfly"))
+    return FALSE;
+
+  return TRUE;
+}
+
 static void
 accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
     TpAccount *account)
@@ -314,7 +345,6 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
   guint                     presence;
   gboolean                  account_enabled;
   gboolean                  creating_account;
-  TpStorageRestrictionFlags storage_restrictions = 0;
   gboolean display_switch = TRUE;
 
   /* do not update the infobar when the account is not selected */
@@ -341,14 +371,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
       if (!account_enabled)
         presence = TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
 
-      storage_restrictions = tp_account_get_storage_restrictions (account);
-      if (storage_restrictions & TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED)
-        display_switch = FALSE;
-
-      /* Butterfly accounts shouldn't be used any more */
-      if (!tp_strdiff (tp_account_get_connection_manager (account),
-            "butterfly"))
-        display_switch = FALSE;
+      display_switch = account_can_be_enabled (account);
     }
   else
     {
@@ -1704,7 +1727,8 @@ accounts_dialog_treeview_enabled_cb (GtkMenuItem *item,
   gboolean enabled;
 
   enabled = tp_account_is_enabled (account);
-  tp_account_set_enabled_async (account, !enabled, NULL, NULL);
+
+  enable_and_connect_account (account, !enabled);
 }
 
 static gboolean
@@ -1762,16 +1786,24 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item_enable);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item_disable);
 
-  if (tp_account_is_enabled (account))
+  if (account_can_be_enabled (account))
     {
-      tp_g_signal_connect_object (item_disable, "activate",
-          G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
-      gtk_widget_set_sensitive (item_enable, FALSE);
+      if (tp_account_is_enabled (account))
+        {
+          tp_g_signal_connect_object (item_disable, "activate",
+              G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
+          gtk_widget_set_sensitive (item_enable, FALSE);
+        }
+      else
+        {
+          tp_g_signal_connect_object (item_enable, "activate",
+              G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
+          gtk_widget_set_sensitive (item_disable, FALSE);
+        }
     }
   else
     {
-      tp_g_signal_connect_object (item_enable, "activate",
-          G_CALLBACK (accounts_dialog_treeview_enabled_cb), account, 0);
+      gtk_widget_set_sensitive (item_enable, FALSE);
       gtk_widget_set_sensitive (item_disable, FALSE);
     }
 
@@ -1974,19 +2006,24 @@ accounts_dialog_add_account (EmpathyAccountsDialog *dialog,
       if (gtk_tree_selection_count_selected_rows (selection) == 0)
         selected = TRUE;
 
-      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+      gtk_list_store_insert_with_values (GTK_LIST_STORE (model), &iter, -1,
+          COL_NAME, name,
+          COL_STATUS, status,
+          COL_ACCOUNT, account,
+          COL_ACCOUNT_SETTINGS, settings,
+          -1);
     }
   else
     {
       selected = gtk_tree_selection_iter_is_selected (selection, &iter);
-    }
 
-  gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-      COL_NAME, name,
-      COL_STATUS, status,
-      COL_ACCOUNT, account,
-      COL_ACCOUNT_SETTINGS, settings,
-      -1);
+      gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+          COL_NAME, name,
+          COL_STATUS, status,
+          COL_ACCOUNT, account,
+          COL_ACCOUNT_SETTINGS, settings,
+          -1);
+    }
 
   if (selected)
     {
@@ -2186,7 +2223,9 @@ maybe_show_salut_dialog (EmpathyAccountsDialog *self)
 
   button = gtk_dialog_add_button (GTK_DIALOG (dialog),
       _("_Connect"), GTK_RESPONSE_YES);
-  gtk_widget_set_sensitive (button, FALSE);
+  gtk_widget_set_sensitive (button,
+      empathy_local_xmpp_assistant_widget_is_valid (
+        EMPATHY_LOCAL_XMPP_ASSISTANT_WIDGET (widget)));
 
   g_signal_connect (widget, "valid", G_CALLBACK (salut_valid_cb),
       button);
