@@ -43,8 +43,6 @@
 #include "empathy-accounts.h"
 #include "empathy-accounts-common.h"
 #include "empathy-accounts-dialog.h"
-#include "empathy-account-assistant.h"
-#include "empathy-auto-salut-account-helper.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
 #include <libempathy/empathy-debug.h>
@@ -54,7 +52,6 @@
 static gboolean only_if_needed = FALSE;
 static gboolean hidden = FALSE;
 static gchar *selected_account_name = NULL;
-static gboolean assistant = FALSE;
 
 static void
 maybe_show_accounts_ui (TpAccountManager *manager,
@@ -66,7 +63,7 @@ maybe_show_accounts_ui (TpAccountManager *manager,
   if (only_if_needed && empathy_accounts_has_non_salut_accounts (manager))
     return;
 
-  empathy_accounts_show_accounts_ui (manager, NULL, assistant, app);
+  empathy_accounts_show_accounts_ui (manager, NULL, app);
 }
 
 static TpAccount *
@@ -123,7 +120,7 @@ account_manager_ready_for_accounts_cb (GObject *source_object,
 
       if (account != NULL)
         {
-          empathy_accounts_show_accounts_ui (manager, account, assistant, app);
+          empathy_accounts_show_accounts_ui (manager, account, app);
           goto out;
         }
       else
@@ -191,10 +188,6 @@ local_cmdline (GApplication *app,
         N_("Initially select given account (eg, "
             "gabble/jabber/foo_40example_2eorg0)"),
         N_("<account-id>") },
-      { "assistant", 'a',
-        0, G_OPTION_ARG_NONE, &assistant,
-        N_("Show account assistant"),
-        NULL },
 
       { NULL }
   };
