@@ -24,8 +24,6 @@
 
 #include <telepathy-glib/telepathy-glib.h>
 
-#include <telepathy-yell/telepathy-yell.h>
-
 #include <libnotify/notification.h>
 
 #include <libempathy/empathy-utils.h>
@@ -185,7 +183,7 @@ find_main_channel (GList *channels)
       channel_type = tp_channel_get_channel_type_id (channel);
 
       if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_STREAMED_MEDIA ||
-          channel_type == TPY_IFACE_QUARK_CHANNEL_TYPE_CALL)
+          channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_CALL)
         return channel;
     }
 
@@ -203,9 +201,9 @@ has_ongoing_calls (EmpathyCallObserver *self)
       GQuark type = tp_channel_get_channel_type_id (channel);
 
       /* Check that Call channels are not ended */
-      if (type == TPY_IFACE_QUARK_CHANNEL_TYPE_CALL &&
-          tpy_call_channel_get_state (TPY_CALL_CHANNEL (channel), NULL, NULL)
-               == TPY_CALL_STATE_ENDED)
+      if (type == TP_IFACE_QUARK_CHANNEL_TYPE_CALL &&
+          tp_call_channel_get_state (TP_CALL_CHANNEL (channel),
+              NULL, NULL, NULL) == TP_CALL_STATE_ENDED)
         continue;
 
       return TRUE;
@@ -372,7 +370,7 @@ empathy_call_observer_init (EmpathyCallObserver *self)
   tp_base_client_take_observer_filter (self->priv->observer,
       tp_asv_new (
         TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-          TPY_IFACE_CHANNEL_TYPE_CALL,
+          TP_IFACE_CHANNEL_TYPE_CALL,
         TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
           TP_HANDLE_TYPE_CONTACT,
         NULL));
