@@ -50,6 +50,7 @@ struct _EmpathyEventManagerClass {
 
 typedef enum {
     EMPATHY_EVENT_TYPE_CHAT,
+    EMPATHY_EVENT_TYPE_VOIP,
     EMPATHY_EVENT_TYPE_CALL,
     EMPATHY_EVENT_TYPE_TRANSFER,
     EMPATHY_EVENT_TYPE_SUBSCRIPTION,
@@ -57,6 +58,7 @@ typedef enum {
     EMPATHY_EVENT_TYPE_PRESENCE_OFFLINE,
     EMPATHY_EVENT_TYPE_INVITATION,
     EMPATHY_EVENT_TYPE_AUTH,
+    EMPATHY_EVENT_TYPE_MENTIONED,
 } EmpathyEventType;
 
 typedef struct {
